@@ -29,6 +29,7 @@ from oslo_utils import units
 import six
 from six.moves import http_client
 
+from cinder.common import constants
 from cinder import context
 from cinder import exception
 from cinder.i18n import _
@@ -867,6 +868,12 @@ class PowerFlexDriver(driver.VolumeDriver):
         connection_properties["scaleIO_volume_id"] = vol_or_snap.provider_id
         connection_properties["config_group"] = self.configuration.config_group
         connection_properties["failed_over"] = self._is_failed_over
+        connection_properties["verify_certificate"] = (
+            self._get_client().verify_certificate
+        )
+        connection_properties["certificate_path"] = (
+            self._get_client().certificate_path
+        )
 
         if vol_size is not None:
             extra_specs = self._get_volumetype_extraspecs(vol_or_snap)
@@ -964,7 +971,7 @@ class PowerFlexDriver(driver.VolumeDriver):
         stats["volume_backend_name"] = backend_name or "powerflex"
         stats["vendor_name"] = "Dell EMC"
         stats["driver_version"] = self.VERSION
-        stats["storage_protocol"] = "scaleio"
+        stats["storage_protocol"] = constants.SCALEIO
         stats["reserved_percentage"] = 0
         stats["QoS_support"] = True
         stats["consistent_group_snapshot_enabled"] = True
@@ -1235,7 +1242,8 @@ class PowerFlexDriver(driver.VolumeDriver):
 
         self.connector.disconnect_volume(connection_properties, volume)
 
-    def copy_image_to_volume(self, context, volume, image_service, image_id):
+    def copy_image_to_volume(self, context, volume, image_service, image_id,
+                             disable_sparse=False):
         """Fetch image from image service and write it to volume."""
 
         LOG.info("Copy image %(image_id)s from image service %(service)s "
@@ -1251,7 +1259,8 @@ class PowerFlexDriver(driver.VolumeDriver):
                                      image_id,
                                      self._sio_attach_volume(volume),
                                      BLOCK_SIZE,
-                                     size=volume.size)
+                                     size=volume.size,
+                                     disable_sparse=disable_sparse)
         finally:
             self._sio_detach_volume(volume)
 
