@@ -29,6 +29,7 @@ from oslo_utils import fileutils
 from oslo_utils import units
 from oslo_utils import uuidutils
 
+from cinder.common import constants
 from cinder import exception
 from cinder.image import image_utils
 from cinder import interface
@@ -92,7 +93,7 @@ class WindowsISCSIDriver(driver.ISCSIDriver):
 
         iscsi_port = self.configuration.target_port
         iscsi_ips = ([self.configuration.target_ip_address] +
-                     self.configuration.iscsi_secondary_ip_addresses)
+                     self.configuration.target_secondary_ip_addresses)
         requested_portals = {':'.join([iscsi_ip, str(iscsi_port)])
                              for iscsi_ip in iscsi_ips}
 
@@ -252,14 +253,16 @@ class WindowsISCSIDriver(driver.ISCSIDriver):
         target_name = self._get_target_name(volume)
         self._tgt_utils.delete_iscsi_target(target_name)
 
-    def copy_image_to_volume(self, context, volume, image_service, image_id):
+    def copy_image_to_volume(self, context, volume, image_service, image_id,
+                             disable_sparse=False):
         """Fetch the image from image_service and create a volume using it."""
         # Convert to VHD and file back to VHD
         vhd_type = self._tgt_utils.get_supported_vhd_type()
         with image_utils.temporary_file(suffix='.vhd') as tmp:
             volume_path = self.local_path(volume)
             image_utils.fetch_to_vhd(context, image_service, image_id, tmp,
-                                     self.configuration.volume_dd_blocksize)
+                                     self.configuration.volume_dd_blocksize,
+                                     disable_sparse=disable_sparse)
             # The vhd must be disabled and deleted before being replaced with
             # the desired image.
             self._tgt_utils.change_wt_disk_status(volume.name,
@@ -334,7 +337,7 @@ class WindowsISCSIDriver(driver.ISCSIDriver):
         data["volume_backend_name"] = backend_name or self.__class__.__name__
         data["vendor_name"] = 'Microsoft'
         data["driver_version"] = self.VERSION
-        data["storage_protocol"] = 'iSCSI'
+        data["storage_protocol"] = constants.ISCSI
         data['total_capacity_gb'] = total_gb
         data['free_capacity_gb'] = free_gb
         data['reserved_percentage'] = self.configuration.reserved_percentage
